@@ -15,7 +15,7 @@ use IO::Lambda qw(:all);
 use IO::Lambda::HTTP qw(http_request);
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new
 {
@@ -230,14 +230,26 @@ sub mime_type
 	}
 }
 
+sub first_value
+{
+	my ($self, $entry) = @_;
+	if ( ref($entry) eq 'HASH') {
+		my $k = (sort keys %$entry)[0];
+		return $entry->{$k};
+	} elsif ( ref($entry) eq 'ARRAY') {
+		return $entry->[0];
+	} else {
+		return "bad entry";
+	}
+}
+
 sub assemble_mail
 {
 	my ( $self, %opt ) = @_;
 
 	my $msg = $opt{message};
-	my $sender = (sort keys %{ $msg->{Sender} })[0];
-	$sender = $msg->{Sender}->{$sender // ''};
-	$sender = $sender->{content} if $sender;
+	my $sender = $self->first_value($msg->{Sender});
+	$sender = $sender->{content} if ref($sender) eq 'HASH';
 	$sender //= 'unknown';
 
 	my $received = $msg->{receivedDateTime} // '';
@@ -257,7 +269,7 @@ sub assemble_mail
 	$received = $date->strftime('%a, %d %b %Y %H:%M:%S %z');
 
 	my $mail = MIME::Entity->build(
-		From          => $opt{from}    // ( encode('MIME-Q', $sender) . ' <noreply@localhost>' ) ,
+		From          => $opt{from}    // ( encode('MIME-Q', $sender) . ' <noreply@e-boks.dk>' ) ,
 		To            => $opt{to}      // ( encode('MIME-Q', $self->{uname}) . ' <' . ( $ENV{USER} // 'you' ) . '@localhost>' ),
 		Subject       => $opt{subject} // encode('MIME-Header', $msg->{name}),
 		Data          => $opt{data}    // encode('utf-8', "Mail from $sender"),
@@ -281,7 +293,7 @@ sub assemble_mail
 		my $entity = $mail->attach(
 			Type     => $self->mime_type($msg),
 			Encoding => 'base64',
-			Data     => $opt{body},
+			Data     => $body,
 			Filename => $fn,
 		);
 
